==> secioss-idsuite-cloud-sp-4.0.1.zip: secioss-idsuite-cloud-sp-4.0.1/opt/secioss/share/simplesamlphp/www/authmemcookie.php <==
<?php

/**
 * This file implements an script which can be used to authenticate users with Auth MemCookie.
 * See: http://authmemcookie.sourceforge.net/
 *
 * The configuration for this script is stored in config/authmemcookie.php.
 *
 * The file extra/auth_memcookie.conf contains an example of how Auth Memcookie can be configured
 * to use simpleSAMLphp.
 */

require_once('_include.php');

try {
	/* Load simpleSAMLphp configuration. */
	$globalConfig = SimpleSAML_Configuration::getInstance();
	$session = SimpleSAML_Session::getInstance();

	/* Check if this module is enabled. */
	if(!$globalConfig->getValue('enable.authmemcookie', FALSE)) {
		SimpleSAML_Utilities::fatalError($session->getTrackID(), 'NOACCESS');
	}

	/* Load Auth MemCookie configuration. */
	$amc = SimpleSAML_AuthMemCookie::getInstance();

        $queryString = array('RelayState' => SimpleSAML_Utilities::selfURL());
	if (preg_match('/back=[^&]+tenant%3D([^%]+)/', $queryString['RelayState'], $matches)) {
		$queryString['tenant'] = $matches[1];
		$metadata = SimpleSAML_Metadata_MetaDataStorageHandler::getMetadataHandler();
		$idpList = $metadata->getList();
                foreach ($idpList as $id => $data) {
			if (isset($data['secioss.tenant']) && $data['secioss.tenant'] == $matches[1]) {
				$queryString['idpentityid'] = $id;
				break;
			}
		}
	}

	/* Check if the user is authorized. We attempt to authenticate the user if not. */
	$loginMethod = $amc->getLoginMethod();
	switch($loginMethod) {
	case 'saml2':
		if (!$session->isValid('saml2') ) {
			SimpleSAML_Utilities::redirect(
				'/' . $globalConfig->getBaseURL() . 'saml2/sp/initSSO.php',
				$queryString
				);
		}
		break;
	case 'shib13':
		if (!$session->isValid('shib13') ) {
			SimpleSAML_Utilities::redirect(
				'/' . $globalConfig->getBaseURL() . 'shib13/sp/initSSO.php',
				$queryString
				);
		}
		break;
	default:
		/* Should never happen, as the login method is checked in the AuthMemCookie class. */
		throw new Exception('Invalid login method.');
	}


	/* Generate session id and save it in a cookie. */
	$sessionID = SimpleSAML_Utilities::generateID();

	$cookieName = $amc->getCookieName();
	setcookie($cookieName, $sessionID, 0, '/', NULL, SimpleSAML_Utilities::isHTTPS());


	/* Generate the authentication information. */

	$attributes = $session->getAttributes();

	$authData = array();

	/* Username. */
	$usernameAttr = $amc->getUsernameAttr();
	if ($usernameAttr == 'nameid') {
		$nameId = $session->getNameID();
		if ($idpmetadata && isset($idpmetadata['nameidattribute'])) {
			$ldapconfig = SimpleSAML_Configuration::getConfig('ldap.php');
			$hostname = $ldapconfig->getValue('auth.ldap.hostname');
			$enable_tls = $ldapconfig->getValue('auth.ldap.enable_tls');
			$ldap = @ldap_connect($hostname);
			if (empty($ldap)) 
				throw new Exception('Error initializing LDAP connection with PHP LDAP library.');
			ldap_set_option($ldap, LDAP_OPT_PROTOCOL_VERSION, 3);
			if (!preg_match("/ldaps:/i",$hostname) and $enable_tls) {
				if (!@ldap_start_tls($ldap)) {
					throw new Exception('Could not force LDAP into TLS-session. Please verify certificates and configuration. Could also be that PHP the LDAP library cannot connect to the LDAP server [' . $hostname . ']: ');
				}
			}

			$searchUsername = $ldapconfig->getValue('auth.ldap.search.username', NULL);
			$searchPassword = $ldapconfig->getValue('auth.ldap.search.password', NULL);
			if($searchUsername === NULL || $searchPassword === NULL) {
				throw new Exception('"auth.ldap.search.username" is configured, but not' .
					' "auth.ldap.search.password".');
			}

			if(!ldap_bind($ldap, $searchUsername, $searchPassword)) {
				throw new Exception('Error authenticating using search username & password.');
			}

			$searchBase = $ldapconfig->getValue('auth.ldap.search.base', NULL);
			if($searchBase === NULL) {
				throw new Exception('"auth.ldap.search.base"' .
					' must be configured before LDAP search can be enabled.');
			}
			if ($tenant) {
				$searchBase = "o=$tenant,$searchBase";
			}

			$searchFilter = $ldapconfig->getValue('auth.ldap.search.filter', NULL);
			if ($searchFilter === NULL) {
				$searchFilter = '('.$idpmetadata['nameidattribute'].'='.$nameId['value'].')';
			} else {
				$searchFilter = '(&('.$idpmetadata['nameidattribute'].'='.$nameId['value'].')'.$searchFilter.')';
			}

			$r = ldap_search($ldap, $searchBase, $searchFilter, array('uid'));
			if (!$r || ldap_count_entries($ldap, $r) !== 1) {
				throw new Exception('The user doesn\'t exist');
			} else {
				$entries = ldap_get_entries($ldap, $r);
				if (isset($entries[0]['uid'])) {
					if (preg_match('/@(.+)$/', $entries[0]['uid'][0], $matches)) {
						$session->setAttribute('tenant',$matches[1]);
					}
					$username = preg_replace('/@[^@]+$/', '', $entries[0]['uid'][0]);
				} else {
					throw new Exception('The user doesn\'t have user id');
				}
			}
		} else {
			$username = $nameId['value'];
		}
		$authData['UserName'] = $username;
	} else {
		if(!array_key_exists($usernameAttr, $attributes)) {
			throw new Exception('The user doesn\'t have an attribute named \'' . $usernameAttr .
				'\'. This attribute is expected to contain the username.');
		}
		$authData['UserName'] = $attributes[$usernameAttr];
	}

	/* Groups. */
	$groupsAttr = $amc->getGroupsAttr();
	if($groupsAttr !== NULL) {
		if(!array_key_exists($groupsAttr, $attributes)) {
			throw new Exception('The user doesn\'t have an attribute named \'' . $groupsAttr .
				'\'. This attribute is expected to contain the groups the user is a member of.');
		}
		$authData['Groups'] = $attributes[$groupsAttr];
	} else {
		$authData['Groups'] = array();
	}

	$authData['RemoteIP'] = $_SERVER['REMOTE_ADDR'];

	foreach($attributes as $n => $v) {
		$authData['ATTR_' . $n] = $v;
	}


	/* Store the authentication data in the memcache server. */

	$data = '';
	foreach($authData as $n => $v) {
		if(is_array($v)) {
			$v = implode(':', $v);
		}

		$data .= $n . '=' . $v . "\r\n";
	}


	$memcache = $amc->getMemcache();
	$memcache->set($sessionID, $data);

	/* Register logout handler. */
	$session->registerLogoutHandler('SimpleSAML_AuthMemCookie', 'logoutHandler');

	/* Redirect the user back to this page to signal that the login is completed. */
	SimpleSAML_Utilities::redirect(SimpleSAML_Utilities::selfURL());
} catch(Exception $e) {
	SimpleSAML_Utilities::fatalError($session->getTrackID(), 'CONFIG', $e);
}

?>

==> secioss-idsuite-cloud-sp-4.0.3.zip: secioss-idsuite-cloud-sp-4.0.3/opt/secioss/share/simplesamlphp/www/authmemcookie.php <==
<?php

/**
 * This file implements an script which can be used to authenticate users with Auth MemCookie.
 * See: http://authmemcookie.sourceforge.net/
 *
 * The configuration for this script is stored in config/authmemcookie.php.
 *
 * The file extra/auth_memcookie.conf contains an example of how Auth Memcookie can be configured
 * to use simpleSAMLphp.
 */

require_once('_include.php');

function ssl_decrypt($string, $keyfile)
{
	$string = base64_decode($string);
	$privatekey = openssl_get_privatekey('file://'.$keyfile);
	if (openssl_private_decrypt($string, $decrypted, $privatekey, OPENSSL_PKCS1_OAEP_PADDING)) {
		return $decrypted;
	}
        return null;
}

function des_encrypt($string, $keyfile)
{
        $content = file_get_contents($keyfile);
        if( $content === false ){
		// Cannot read key file
		return null;
        }

        if(preg_match( "/^\s*TKTAuthSecret\s+\"(.*?)\"/mi", $content, $matches)) {
		$key = $matches[1];
        } else {
		return null;
	}

	srand((double) microtime() * 1000000);
	$key = md5($key);
	$string = $key.$string;

	$td = mcrypt_module_open('tripledes', '', 'cfb', '');
	$key = substr($key, 0, mcrypt_enc_get_key_size($td));
	$iv_size = mcrypt_enc_get_iv_size($td);
	$iv = mcrypt_create_iv($iv_size, MCRYPT_RAND);

	if (mcrypt_generic_init($td, $key, $iv) != -1) {
		$c_t = mcrypt_generic($td, $string);
		mcrypt_generic($td, $string);
		mcrypt_module_close($td);
		$c_t = $iv.$c_t;
		return base64_encode($c_t);
	}

	return null;
}

try {
	/* Load simpleSAMLphp configuration. */
	$globalConfig = SimpleSAML_Configuration::getInstance();
	$session = SimpleSAML_Session::getInstance();

	/* Check if this module is enabled. */
	if(!$globalConfig->getValue('enable.authmemcookie', FALSE)) {
		SimpleSAML_Utilities::fatalError($session->getTrackID(), 'NOACCESS');
	}

	/* Load Auth MemCookie configuration. */
	$amc = SimpleSAML_AuthMemCookie::getInstance();

        $queryString = array('RelayState' => SimpleSAML_Utilities::selfURL());
	if (preg_match('/back=[^&]+tenant%3D([^%]+)/', $queryString['RelayState'], $matches)) {
		$queryString['tenant'] = $matches[1];
		$metadata = SimpleSAML_Metadata_MetaDataStorageHandler::getMetadataHandler();
		$idpList = $metadata->getList();
                foreach ($idpList as $id => $data) {
			if (isset($data['secioss.tenant']) && $data['secioss.tenant'] == $matches[1]) {
				$queryString['idpentityid'] = $id;
				break;
			}
		}
	}

	/* Check if the user is authorized. We attempt to authenticate the user if not. */
	$loginMethod = $amc->getLoginMethod();
	switch($loginMethod) {
	case 'saml2':
		if (!$session->isValid('saml2') ) {
			SimpleSAML_Utilities::redirect(
				'/' . $globalConfig->getBaseURL() . 'saml2/sp/initSSO.php',
				$queryString
				);
		}
		break;
	case 'shib13':
		if (!$session->isValid('shib13') ) {
			SimpleSAML_Utilities::redirect(
				'/' . $globalConfig->getBaseURL() . 'shib13/sp/initSSO.php',
				$queryString
				);
		}
		break;
	default:
		/* Should never happen, as the login method is checked in the AuthMemCookie class. */
		throw new Exception('Invalid login method.');
	}


	/* Generate session id and save it in a cookie. */
	$sessionID = SimpleSAML_Utilities::generateID();

	$cookieName = $amc->getCookieName();
	setcookie($cookieName, $sessionID, 0, '/'.(dirname($globalConfig->getBaseURL()) != '.' ? dirname($globalConfig->getBaseURL()) : ''), NULL, SimpleSAML_Utilities::isHTTPS());


	/* Generate the authentication information. */

	$attributes = $session->getAttributes();

	$authData = array();

	/* Username. */
	$usernameAttr = $amc->getUsernameAttr();
	if ($usernameAttr == 'nameid') {
		$nameId = $session->getNameID();
		if ($idpmetadata && isset($idpmetadata['nameidattribute'])) {
			$ldapconfig = SimpleSAML_Configuration::getConfig('ldap.php');
			$hostname = $ldapconfig->getValue('auth.ldap.hostname');
			$enable_tls = $ldapconfig->getValue('auth.ldap.enable_tls');
			$ldap = @ldap_connect($hostname);
			if (empty($ldap)) 
				throw new Exception('Error initializing LDAP connection with PHP LDAP library.');
			ldap_set_option($ldap, LDAP_OPT_PROTOCOL_VERSION, 3);
			if (!preg_match("/ldaps:/i",$hostname) and $enable_tls) {
				if (!@ldap_start_tls($ldap)) {
					throw new Exception('Could not force LDAP into TLS-session. Please verify certificates and configuration. Could also be that PHP the LDAP library cannot connect to the LDAP server [' . $hostname . ']: ');
				}
			}

			$searchUsername = $ldapconfig->getValue('auth.ldap.search.username', NULL);
			$searchPassword = $ldapconfig->getValue('auth.ldap.search.password', NULL);
			if($searchUsername === NULL || $searchPassword === NULL) {
				throw new Exception('"auth.ldap.search.username" is configured, but not' .
					' "auth.ldap.search.password".');
			}

			if(!ldap_bind($ldap, $searchUsername, $searchPassword)) {
				throw new Exception('Error authenticating using search username & password.');
			}

			$searchBase = $ldapconfig->getValue('auth.ldap.search.base', NULL);
			if($searchBase === NULL) {
				throw new Exception('"auth.ldap.search.base"' .
					' must be configured before LDAP search can be enabled.');
			}
			if ($tenant) {
				$searchBase = "o=$tenant,$searchBase";
			}

			$searchFilter = $ldapconfig->getValue('auth.ldap.search.filter', NULL);
			if ($searchFilter === NULL) {
				$searchFilter = '('.$idpmetadata['nameidattribute'].'='.$nameId['value'].')';
			} else {
				$searchFilter = '(&('.$idpmetadata['nameidattribute'].'='.$nameId['value'].')'.$searchFilter.')';
			}

			$r = ldap_search($ldap, $searchBase, $searchFilter, array('uid'));
			if (!$r || ldap_count_entries($ldap, $r) !== 1) {
				throw new Exception('The user doesn\'t exist');
			} else {
				$entries = ldap_get_entries($ldap, $r);
				if (isset($entries[0]['uid'])) {
					if (preg_match('/@(.+)$/', $entries[0]['uid'][0], $matches)) {
						$session->setAttribute('tenant',$matches[1]);
					}
					$username = preg_replace('/@[^@]+$/', '', $entries[0]['uid'][0]);
				} else {
					throw new Exception('The user doesn\'t have user id');
				}
			}
		} else {
			$username = $nameId['value'];
		}
		$authData['UserName'] = $username;
	} else {
		if(!array_key_exists($usernameAttr, $attributes)) {
			throw new Exception('The user doesn\'t have an attribute named \'' . $usernameAttr .
				'\'. This attribute is expected to contain the username.');
		}
		$authData['UserName'] = $attributes[$usernameAttr];
	}

	/* Groups. */
	$groupsAttr = $amc->getGroupsAttr();
	if($groupsAttr !== NULL) {
		if(!array_key_exists($groupsAttr, $attributes)) {
			throw new Exception('The user doesn\'t have an attribute named \'' . $groupsAttr .
				'\'. This attribute is expected to contain the groups the user is a member of.');
		}
		$authData['Groups'] = $attributes[$groupsAttr];
	} else {
		$authData['Groups'] = array();
	}

	$authData['RemoteIP'] = $_SERVER['REMOTE_ADDR'];

	foreach($attributes as $n => $v) {
		if ($n == 'seciossEncryptedPassword') {
			$autologin_conf = parse_ini_file("/opt/secioss/var/www/conf/config.ini", true);
			if ($autologin_conf && isset($autologin_conf['autologin']['privatekey'])) {
				$v[0] = ssl_decrypt($v[0], $autologin_conf['autologin']['privatekey']);
				if (!$v[0]) {
					throw new Exception("Encrypted password is invalid.");
				}
				$v[0] = des_encrypt($v[0], '/opt/secioss/etc/auth_tkt.conf');
				if (!$v[0]) {
					throw new Exception("Can't encrypt password.");
				}
			}
			$authData['Password'] = $v;
		} else {
			$authData['ATTR_' . $n] = $v;
		}
	}


	/* Store the authentication data in the memcache server. */

	$data = '';
	foreach($authData as $n => $v) {
		if(is_array($v)) {
			$v = implode(':', $v);
		}

		$data .= $n . '=' . $v . "\r\n";
	}


	$memcache = $amc->getMemcache();
	$memcache->set($sessionID, $data);

	/* Register logout handler. */
	$session->registerLogoutHandler('SimpleSAML_AuthMemCookie', 'logoutHandler');

	/* Redirect the user back to this page to signal that the login is completed. */
	SimpleSAML_Utilities::redirect(SimpleSAML_Utilities::selfURL());
} catch(Exception $e) {
	SimpleSAML_Utilities::fatalError($session->getTrackID(), 'CONFIG', $e);
}

?>
